"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var os_1 = tslib_1.__importDefault(require("os"));
var tsconfig_paths_webpack_plugin_1 = tslib_1.__importDefault(require("tsconfig-paths-webpack-plugin"));
var fork_ts_checker_webpack_plugin_1 = tslib_1.__importDefault(require("fork-ts-checker-webpack-plugin"));
var disableCaching = String(process.env.BUILD_CACHE_DISABLED).toLowerCase() === 'true';
var disableTypeCheck = process.env.START_FAST_MODE === 'true';
var osCpus = os_1.default.cpus().length;
var threadLoaderCpus = !disableTypeCheck ? osCpus - 1 : osCpus;
var threadLoader = {
    loader: 'thread-loader',
    options: {
        // there should be 1 cpu for the fork-ts-checker-webpack-plugin if its enabled
        workers: threadLoaderCpus,
    },
};
var cacheLoader = function (cacheDirectory) {
    return {
        loader: 'cache-loader',
        options: {
            cacheDirectory: cacheDirectory,
        },
    };
};
function getTypeScriptWebpackRule(plugins, resolvePlugins, options, buildTarget) {
    if (!disableTypeCheck) {
        plugins.push(new fork_ts_checker_webpack_plugin_1.default({ checkSyntacticErrors: true })); // fork ts checking
    }
    var configFile = buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT;
    var tsConfigPathsPluginConfig = {};
    var tsLoaderOptions = {
        happyPackMode: true,
        transpileOnly: true,
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new tsconfig_paths_webpack_plugin_1.default(tsConfigPathsPluginConfig));
    var tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    return {
        test: /\.tsx?$/,
        use: !disableCaching
            ? [threadLoader, cacheLoader(options.cacheDirectory), tsLoader]
            : [threadLoader, tsLoader],
    };
}
exports.getTypeScriptWebpackRule = getTypeScriptWebpackRule;
//# sourceMappingURL=ts-loader-config.js.map