import os from 'os';
import TsconfigPathsPlugin from 'tsconfig-paths-webpack-plugin';
import ForkTsCheckerWebpackPlugin from 'fork-ts-checker-webpack-plugin';
const disableCaching = String(process.env.BUILD_CACHE_DISABLED).toLowerCase() === 'true';
const disableTypeCheck = process.env.START_FAST_MODE === 'true';
const osCpus = os.cpus().length;
const threadLoaderCpus = !disableTypeCheck ? osCpus - 1 : osCpus;
const threadLoader = {
    loader: 'thread-loader',
    options: {
        // there should be 1 cpu for the fork-ts-checker-webpack-plugin if its enabled
        workers: threadLoaderCpus,
    },
};
const cacheLoader = (cacheDirectory) => {
    return {
        loader: 'cache-loader',
        options: {
            cacheDirectory,
        },
    };
};
export function getTypeScriptWebpackRule(plugins, resolvePlugins, options, buildTarget) {
    if (!disableTypeCheck) {
        plugins.push(new ForkTsCheckerWebpackPlugin({ checkSyntacticErrors: true })); // fork ts checking
    }
    const configFile = buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT;
    const tsConfigPathsPluginConfig = {};
    const tsLoaderOptions = {
        happyPackMode: true,
        transpileOnly: true,
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new TsconfigPathsPlugin(tsConfigPathsPluginConfig));
    const tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    return {
        test: /\.tsx?$/,
        use: !disableCaching
            ? [threadLoader, cacheLoader(options.cacheDirectory), tsLoader]
            : [threadLoader, tsLoader],
    };
}
//# sourceMappingURL=ts-loader-config.js.map